from .writer import capture_security_logs  # noqa: F401

default_app_config = 'security.backends.testing.app.SecurityTestingBackend'
